"""Uncomplicated OOP command line argument parser."""
from .argument import Argument, Mutex
from .command import Command, SubCommand
from .root import Root
from .progressbar import ProgressBar


__version__ = '1.9.1'
